resultSet.ArrayResultSet

|  | ## Cheshire3 Object Model: Class ArrayResultSet

Module resultSet :: Class ArrayResultSet

## Class ArrayResultSet
source code

Object Tree:

    baseObjects.ResultSet --+
                            |
              RankedResultSet --+
                                |
                  SimpleResultSet --+
                                    |
                                   ArrayResultSet

Instance Methods

__init__(self, session, data, recordStore=None)
__getitem__(self, k)
__len__(self)
_toBitmap(self, session)
_lrAssign(self, session, others, clause, cql, db)
_coriAssign(self, session, others, clause, cql, db)
_tfidfAssign(self, session, others, clause, cql, db)
_meanWeightsArray(self, items, n)
_sumWeightsArray(self, items, n)
SLOW_combine(self, session, others, clause, db=None)
combine(self, session, others, clause, db=None)
order(self, session, spec)
reverse(self, session)
Inherited from `SimpleResultSet`: `append`, `deserialise`, `extend`, `fromList`, `retrieve`, `scale_weights`, `serialise` Inherited from `RankedResultSet` (private): `_cmbzWeights`, `_meanWeights`, `_normWeights`, `_nprvWeights`, `_pivotWeights`, `_sumWeights` Inherited from `baseObjects.ResultSet`: `sort`

Class Variables

_array |
recordStore |
proxInfo |
Inherited from `SimpleResultSet`: `expires`, `id`, `index`, `maxWeight`, `minWeight`, `queryFragment`, `queryFreq`, `queryPositions`, `queryTerm`, `relevancy`, `termWeight`, `termid`, `totalOccs`, `totalRecs` Inherited from `SimpleResultSet` (private): `_list`

Method Details

### __init__(self, session, data, recordStore=None) (Constructor) | source code
Overrides: SimpleResultSet.__init__

### __getitem__(self, k) (Indexing operator) | source code
Overrides: SimpleResultSet.__getitem__

### __len__(self) (Length operator) | source code
Overrides: SimpleResultSet.__len__

### _toBitmap(self, session) | source code

### _lrAssign(self, session, others, clause, cql, db) | source code
Overrides: SimpleResultSet._lrAssign

### _coriAssign(self, session, others, clause, cql, db) | source code
Overrides: SimpleResultSet._coriAssign

### _tfidfAssign(self, session, others, clause, cql, db) | source code
Overrides: SimpleResultSet._tfidfAssign

### _meanWeightsArray(self, items, n) | source code

### _sumWeightsArray(self, items, n) | source code

### SLOW_combine(self, session, others, clause, db=None) | source code

### combine(self, session, others, clause, db=None) | source code
Overrides: SimpleResultSet.combine

### order(self, session, spec) | source code
Overrides: SimpleResultSet.order

### reverse(self, session) | source code
Overrides: SimpleResultSet.reverse

Class Variable Details

    ### _array Value:
        None

    ### recordStore Value:
        None

    ### proxInfo Value:
        {}